# Generated by Django 3.1.13 on 2021-09-03 07:14

import django.contrib.gis.db.models.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djangostreetmap", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="OsmHighway",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("geom", django.contrib.gis.db.models.fields.MultiLineStringField(srid=3857)),
                ("name", models.TextField(blank=True, null=True)),
                ("highway", models.TextField()),
            ],
        ),
    ]
